@@ -52,12 +52,12 @@ namespace gtsam {
    *  algorithms.  Any factor graph holding eliminateable factors can derive from this class to
    *  expose functions for computing marginals, conditional marginals, doing multifrontal and
    *  sequential elimination, etc. */
-  template<class FACTORGRAPH>
+  template<class FACTOR_GRAPH>
   class EliminateableFactorGraph
   {
   private:
-    typedef EliminateableFactorGraph<FACTORGRAPH> This; ///< Typedef to this class.
-    typedef FACTORGRAPH FactorGraphType; ///< Typedef to factor graph type
+    typedef EliminateableFactorGraph<FACTOR_GRAPH> This; ///< Typedef to this class.
+    typedef FACTOR_GRAPH FactorGraphType; ///< Typedef to factor graph type
     // Base factor type stored in this graph (private because derived classes will get this from
     // their FactorGraph base class)
     typedef typename EliminationTraits<FactorGraphType>::FactorType _FactorType;
@@ -139,7 +139,7 @@ namespace gtsam {
       OptionalVariableIndex variableIndex = boost::none) const;
 
     /** Do multifrontal elimination of all variables to produce a Bayes tree.  If an ordering is not
-     *  provided, the ordering will be computed using either COLAMD or METIS, dependeing on
+     *  provided, the ordering will be computed using either COLAMD or METIS, depending on
      *  the parameter orderingType (Ordering::COLAMD or Ordering::METIS)
      *
      *  <b> Example - Full Cholesky elimination in COLAMD order: </b>
@@ -160,7 +160,7 @@ namespace gtsam {
       OptionalVariableIndex variableIndex = boost::none) const;
 
     /** Do multifrontal elimination of all variables to produce a Bayes tree.  If an ordering is not
-     *  provided, the ordering will be computed using either COLAMD or METIS, dependeing on
+     *  provided, the ordering will be computed using either COLAMD or METIS, depending on
      *  the parameter orderingType (Ordering::COLAMD or Ordering::METIS)
      *
      *  <b> Example - Full QR elimination in specified order:
